@@ -1,6 +1,7 @@
 import re
 
-from .memoize import memoize
+from robot.libraries.BuiltIn import BuiltIn
+
 from .robotlib import ImportedLibraryDocBuilder, get_libs
 from .robotvar import assign_variable
 
@@ -11,6 +12,8 @@ except ImportError:
 
 KEYWORD_SEP = re.compile('  +|\t')
 
+_lib_keywords_cache = {}
+
 
 def parse_keyword(command):
     """Split a robotframework keyword string."""
@@ -18,21 +21,22 @@ def parse_keyword(command):
     return KEYWORD_SEP.split(command)
 
 
-@memoize
-def get_lib_keywords(library, long_format=False):
+def get_lib_keywords(library):
     """Get keywords of imported library."""
+    if library.name in _lib_keywords_cache:
+        return _lib_keywords_cache[library.name]
+
     lib = ImportedLibraryDocBuilder().build(library)
     keywords = []
     for keyword in lib.keywords:
-        if long_format:
-            doc = keyword.doc
-        else:
-            doc = keyword.doc.split('\n')[0]
         keywords.append({
             'name': keyword.name,
             'lib': library.name,
-            'doc': doc,
+            'doc': keyword.doc,
+            'summary': keyword.doc.split('\n')[0],
         })
+
+    _lib_keywords_cache[library.name] = keywords
     return keywords
 
 
@@ -42,6 +46,29 @@ def get_keywords():
         yield from get_lib_keywords(lib)
 
 
+def find_keyword(keyword_name):
+    keyword_name = keyword_name.lower()
+    return [keyword
+            for lib in get_libs()
+            for keyword in get_lib_keywords(lib)
+            if keyword['name'].lower() == keyword_name]
+
+
+def _execute_variable(robot_instance, variable_name, keyword, args):
+    variable_only = not args
+    if variable_only:
+        display_value = ['Log to console', keyword]
+        robot_instance.run_keyword(*display_value)
+    else:
+        variable_value = assign_variable(
+            robot_instance,
+            variable_name,
+            args,
+        )
+        echo = '{0} = {1!r}'.format(variable_name, variable_value)
+        return ('#', echo)
+
+
 def run_keyword(robot_instance, keyword):
     """Run a keyword in robotframewrk environment."""
     if not keyword:
@@ -57,19 +84,16 @@ def run_keyword(robot_instance, keyword):
 
     variable_name = keyword.rstrip('= ')
     if is_variable(variable_name):
-        variable_only = not args
-        if variable_only:
-            display_value = ['Log to console', keyword]
-            robot_instance.run_keyword(*display_value)
-        else:
-            variable_value = assign_variable(
-                robot_instance,
-                variable_name,
-                args,
-            )
-            echo = '{0} = {1!r}'.format(variable_name, variable_value)
-            return ('#', echo)
+        return _execute_variable(robot_instance, variable_name, keyword, args)
     else:
         output = robot_instance.run_keyword(keyword, *args)
         if output:
             return ('<', repr(output))
+
+
+def run_debug_if(condition, *args):
+    """Runs DEBUG if condition is true."""
+
+    return BuiltIn().run_keyword_if(condition,
+                                    'DebugLibrary.DEBUG',
+                                    *args)
